# Tests Documentation

## Unit Tests

To run all unit tests in the `NativeUI/tests/unittests` dir on a Raspberry Pi or VM, run the following 
(adjust the full path to your NativeUI directory accordingly):

```bash
. .hev_env/bin/activate
export PYTHONPATH=/home/pi/hev/NativeUI
pytest NativeUI/tests/unittests
```

To run a single unit test file, set the environment as above and specify the test file:

```bash
pytest NativeUI/tests/unittests/test_hevclient.py
```

## Integration Tests

To run all integration tests, the Arduino emulator and hevserver processes first need to be running, and 
then run all integrations tests in the `NativeUI/tests/integration` dir:

```bash
. .hev_env/bin/activate
export PYTHONPATH=/home/pi/hev/NativeUI
./raspberry-dataserver/ArduinoEmulator.py -f raspberry-dataserver/share/B6-20201207.dump &
./raspberry-dataserver/hevserver.py --use-dump-data &
pytest NativeUI/tests/integration
```

### Coverage

To get pytest coverage run from the root of the repo:

```bash
pip install pytest-cov
pytest --cov=NativeUI NativeUI
```

## SOUP CVEs Testing

To test for Common Vulnerabilities and Exposures (CVEs) in the Software of Unknown Provence (SOUP) use the Dockerfile to build a docker image:

```bash
docker build -t hplv .
```

The docker image can then be scanned using `docker scan` which utilizes the [synk](https://snyk.io/) engine:

```bash
docker scan --file Dockerfile --exclude-base hplv
```
